hepconvert.parquet_to_root
==========================

Defined in `hepconvert.parquet_to_root <https://github.com/zbilodea/hepconvert/blob/52e6cbfbbf81c669ca31b8a538d8f3e8984b35a5/src/hepconvert/parquet_to_root.py>`__ on `line 11 <https://github.com/zbilodea/hepconvert/blob/52e6cbfbbf81c669ca31b8a538d8f3e8984b35a5/src/hepconvert/parquet_to_root.py#L11>`__.

.. autofunction:: hepconvert.parquet_to_root
